Struct ClientRouter
pub struct ClientRouter {
pub uri: String,
pub timeout_s: f64,
/* private fields */
}Expand description
Base client router for the REST API.
Fields
uri: StringThe fully qualified router URI ({uri}/{prefix}/).
timeout_s: f64The request timeout in seconds.
Implementations
impl ClientRouter
impl ClientRouter
pub fn new(uri: &str, prefix: &str, timeout_s: f64, http: Client) -> Self
pub fn new(uri: &str, prefix: &str, timeout_s: f64, http: Client) -> Self
Creates a new router rooted at uri with the given prefix.
The http client is shared with all other routers of the same
VisuClient.